@@ -1,3 +1,5 @@
+#!/usr/bin/env python
+# coding:utf-8
 ##############################################################################
 #The MIT License (MIT)
 #
@@ -30,7 +32,7 @@ import decimal
 import datetime
 import time
 
-VERSION = (0, 2, 4)
+VERSION = (0, 2, 5)
 __version__ = '%s.%s.%s' % VERSION
 apilevel = '2.0'
 threadsafety = 1
@@ -490,6 +492,8 @@ class Connection(object):
             elif code == PG_B_BACKEND_KEY_DATA:
                 DEBUG_OUTPUT("BACKEND_KEY_DATA:", HEX(data))
             elif code == PG_B_COMMAND_COMPLETE:
+                if not obj:
+                    continue
                 command = data[:-1].decode('ascii')
                 DEBUG_OUTPUT("COMMAND_COMPLETE:", command)
                 if command == 'SHOW':
@@ -502,6 +506,8 @@ class Connection(object):
                             obj._current_row = -1
                             break
             elif code == PG_B_ROW_DESCRIPTION:
+                if not obj:
+                    continue
                 DEBUG_OUTPUT("ROW_DESCRIPTION:", HEX(data))
                 count = _bytes_to_bint(data[0:2])
                 obj.description = [None] * count
@@ -528,6 +534,8 @@ class Connection(object):
                     idx += 1
                 DEBUG_OUTPUT('\t\t', obj.description)
             elif code == PG_B_DATA_ROW:
+                if not obj:
+                    continue
                 DEBUG_OUTPUT("DATA_ROW:", HEX(data))
                 n = 2
                 row = []
@@ -619,13 +627,15 @@ class Connection(object):
                 self.sock = ssl.wrap_socket(self.sock)
             else:
                 raise InterfaceError("Server refuses SSL")
-        self.sock.settimeout(self.timeout)
-        v = b''.join([
-            _bint_to_bytes(196608, 4),  # protocol version 3.0
-            b'user\x00', self.user.encode('ascii'), b'\x00',
-            b'database\x00', self.database.encode('ascii'), b'\x00',
-            b'\x00',
-        ])
+        if self.timeout is not None:
+            self.sock.settimeout(float(self.timeout))
+        # protocol version 3.0
+        v = _bint_to_bytes(196608, 4)
+        v += b'user\x00' + self.user.encode('ascii') + b'\x00'
+        if self.database:
+            v += b'database\x00' + self.database.encode('ascii') + b'\x00'
+        v += b'\x00'
+
         self._write(_bint_to_bytes(len(v) + 4, 4) + v)
         self._process_messages()
 
@@ -636,7 +646,7 @@ class Connection(object):
     def cursor(self):
         return Cursor(self)
 
-    def execute(self, query, obj):
+    def execute(self, query, obj=None):
         if not self.in_transaction:
             self.begin()
         DEBUG_OUTPUT('Connection::execute()', query)
@@ -681,7 +691,7 @@ class Connection(object):
             self.sock.close()
             self.sock = None
 
-def connect(host, user, password, database, port=5432, timeout=60, use_ssl=False):
+def connect(host, user, password='', database=None, port=5432, timeout=None, use_ssl=False):
     return Connection(user, password, database, host, port, timeout, use_ssl)
 
 
